diff --git a/include/QueryGenerator/QueryGenerator.php b/include/QueryGenerator/QueryGenerator.php
index 40932b8b46d98b6756c59277dc07bc70a4e80048..5e4e13d145ba559be839d04e4f97aa71db5537dc 100644
--- a/include/QueryGenerator/QueryGenerator.php
+++ b/include/QueryGenerator/QueryGenerator.php
@@ -550,7 +550,12 @@ class QueryGenerator {
 		}
 		$ownerFields = $this->meta->getOwnerFields();
 		if (count($ownerFields) > 0) {
-			$ownerField = $ownerFields[0];
+			//there are more than one field pointing to the users table, the real one is the one called assigned_user_id if there is one, otherwise pick the first
+			if(in_array("assigned_user_id",$ownerFields)){
+				$ownerField="assigned_user_id";
+			}else{
+				$ownerField = $ownerFields[0];
+			}
 		}
 		$baseTable = $this->meta->getEntityBaseTable();
 		$sql = " FROM $baseTable ";
diff --git a/languages/en_us/Vtiger.php b/languages/en_us/Vtiger.php
index 1d71eea16a8f8407ec724b84331d86fa179f3d34..902afa0d8b5087aeb018c33f8f752f9b43a43345 100644
--- a/languages/en_us/Vtiger.php
+++ b/languages/en_us/Vtiger.php
@@ -764,7 +764,7 @@ $jsLanguageStrings = array(
 	'JS_VALUE_SHOULD_NOT_BE_LESS_THAN' => 'Frequency of any cron job configured should not be less than',
 	'JS_YOU_ARE_IN_PAGE_NUMBER' => 'You are in page number',
 	'JS_YOU_CAN_SELECT_ONLY' => 'You can select only',
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'LBL_DELETE_CONFIRMATION' => 'Are you sure you want to delete?', // This is added as duplicate as we need to show different message for different modules. Ex:Accounts has different message
 	'LBL_DELETE_USER_CONFIRMATION' => 'When a User is deleted, the user will be marked as "Inactive" and no new records can be assigned to the User, and the user will not be able to login. Are you sure you want to delete?',
 	'LBL_RESTORE_CONFIRMATION' => 'Records previously assigned to this user will not be restored. Are you sure you want to restore this user?',
@@ -798,4 +798,4 @@ $jsLanguageStrings = array(
     
     //Mass edit failure
     'JS_MASS_EDIT_NOT_SUCCESSFULL' => 'Mass edit of some record is not successfull',
-);
\ No newline at end of file
+);
diff --git a/layouts/vlayout/modules/PriceBooks/ListPriceUpdate.tpl b/layouts/vlayout/modules/PriceBooks/ListPriceUpdate.tpl
index f94cb2f56b4ff94c6c951c5fe9aa1fb1aa5cc96a..40e94384afd68494f306a9b7769c82217d4dad8b 100644
--- a/layouts/vlayout/modules/PriceBooks/ListPriceUpdate.tpl
+++ b/layouts/vlayout/modules/PriceBooks/ListPriceUpdate.tpl
@@ -25,7 +25,7 @@
 				<span><strong>{vtranslate('LBL_EDIT_LIST_PRICE',$MODULE)}</strong></span>
 				&nbsp;:&nbsp;
 				<input type="text" name="currentPrice" value="{$CURRENT_PRICE}" data-validation-engine="validate[required,funcCall[Vtiger_Currency_Validator_Js.invokeValidation]]" 
-						   data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' />
+						   data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' />
 			</div>
 		</div>
 		{include file='ModalFooter.tpl'|@vtemplate_path:$MODULE}
diff --git a/layouts/vlayout/modules/PriceBooks/ProductPriceBookPopupContents.tpl b/layouts/vlayout/modules/PriceBooks/ProductPriceBookPopupContents.tpl
index 4604087959628009fdc88cc675a09c940d9ac5e0..1d7555b1d6db4b9c662c735caf7dc70a760af9ac 100755
--- a/layouts/vlayout/modules/PriceBooks/ProductPriceBookPopupContents.tpl
+++ b/layouts/vlayout/modules/PriceBooks/ProductPriceBookPopupContents.tpl
@@ -62,7 +62,7 @@
 				<td class="listViewEntryValue {$WIDTHTYPE}">
 					<div class="row-fluid">
 						<input type="text" value="{$LISTVIEW_ENTRY->get('unit_price')}" name="listPrice" class="invisible span10 zeroPaddingAndMargin" data-validation-engine="validate[required,funcCall[Vtiger_Currency_Validator_Js.invokeValidation]]"
-							   data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}'/>
+							   data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}'/>
 					</div>
 				</td>
 			</tr>
diff --git a/layouts/vlayout/modules/Products/MoreCurrenciesList.tpl b/layouts/vlayout/modules/Products/MoreCurrenciesList.tpl
index 8e50451a6908529b9c5e58aee045ba8b562d3656..043bfc869341103e4dfd4e8c4ec05be00cac0d18 100644
--- a/layouts/vlayout/modules/Products/MoreCurrenciesList.tpl
+++ b/layouts/vlayout/modules/Products/MoreCurrenciesList.tpl
@@ -51,7 +51,7 @@
 						</td>
 						<td>
 							<div class="row-fluid">
-								<input {$disable_value} type="text" size="10" class="span9 convertedPrice" name="{$price.curname}" id="{$price.curname}" value="{$price.curvalue}" data-validation-engine="validate[funcCall[Vtiger_Currency_Validator_Js.invokeValidation]]" data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' />
+								<input {$disable_value} type="text" size="10" class="span9 convertedPrice" name="{$price.curname}" id="{$price.curname}" value="{$price.curvalue}" data-validation-engine="validate[funcCall[Vtiger_Currency_Validator_Js.invokeValidation]]" data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' />
 							</div>
 						</td>
 						<td>
diff --git a/layouts/vlayout/modules/Products/PriceBookProductPopupContents.tpl b/layouts/vlayout/modules/Products/PriceBookProductPopupContents.tpl
index a3622b42e17eecf36e9d591f9f1335e30d8ab7b5..fda05f60da7d48d68e5e7bb17e3eb9bf48d38c59 100644
--- a/layouts/vlayout/modules/Products/PriceBookProductPopupContents.tpl
+++ b/layouts/vlayout/modules/Products/PriceBookProductPopupContents.tpl
@@ -58,7 +58,7 @@
 				<td class="listViewEntryValue {$WIDTHTYPE}">
 					<div class="row-fluid">
 						<input type="text" value="{$LISTVIEW_ENTRY->get('unit_price')}" name="listPrice" class="invisible span10 zeroPaddingAndMargin" data-validation-engine="validate[required,funcCall[Vtiger_Currency_Validator_Js.invokeValidation]]"
-							   data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}'/>
+							   data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}'/>
 					</div>
 				</td>
 			</tr>
diff --git a/layouts/vlayout/modules/Settings/LayoutEditor/FieldUi.tpl b/layouts/vlayout/modules/Settings/LayoutEditor/FieldUi.tpl
index ec34f9c53431b73a4a8deb2e5ccc7f0f3059f6b6..c10894e1d6ca8c92c6845f4de23f159814a65fd2 100644
--- a/layouts/vlayout/modules/Settings/LayoutEditor/FieldUi.tpl
+++ b/layouts/vlayout/modules/Settings/LayoutEditor/FieldUi.tpl
@@ -105,7 +105,7 @@
 											<span class="add-on">{$USER_MODEL->get('currency_symbol')}</span>
 											<input type="text" class="input-medium" name="fieldDefaultValue" {if !$FIELD_MODEL->hasDefaultValue()} disabled="" {/if} data-validation-engine="validate[required,funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" 
 												data-fieldinfo='{ZEND_JSON::encode($FIELD_INFO)}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('defaultvalue'))}" 
-												data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' />
+												data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' />
 										</div>
 									{else}
 										<input type="text" {if !$FIELD_MODEL->hasDefaultValue()} disabled="" {/if} data-validation-engine="validate[required,funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" class="input-medium" name="fieldDefaultValue" value="{$FIELD_MODEL->get('defaultvalue')}" data-fieldinfo='{ZEND_JSON::encode($FIELD_INFO)}'/>
diff --git a/layouts/vlayout/modules/Settings/LayoutEditor/Index.tpl b/layouts/vlayout/modules/Settings/LayoutEditor/Index.tpl
index af3548d7e88d927a9b21cd3f341a87e217c3e4e7..75026ae4be5211de6add23fbce160bafba023bd1 100644
--- a/layouts/vlayout/modules/Settings/LayoutEditor/Index.tpl
+++ b/layouts/vlayout/modules/Settings/LayoutEditor/Index.tpl
@@ -222,7 +222,7 @@
                                                                 <span class="add-on">{$USER_MODEL->get('currency_symbol')}</span>
                                                                 <input type="text" data-validation-engine="validate[required,funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" {if !$FIELD_MODEL->hasDefaultValue()} disabled="" {/if}  class="input-medium" name="fieldDefaultValue"
                                                                        data-fieldinfo='{ZEND_JSON::encode($FIELD_INFO)}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('defaultvalue'))}"
-                                                                       data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' />
+                                                                       data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' />
                                                             </div>
                                                         {else if $FIELD_MODEL->getFieldName() eq "terms_conditions" && $FIELD_MODEL->get('uitype') == 19}
                                                             {assign var=INVENTORY_TERMS_AND_CONDITIONS_MODEL value= Settings_Vtiger_MenuItem_Model::getInstance("INVENTORYTERMSANDCONDITIONS")}
@@ -387,7 +387,7 @@
                                 <span class="add-on">{$USER_MODEL->get('currency_symbol')}</span>
                                 <input type="text" data-validation-engine="validate[required,funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" {if !$FIELD_MODEL->hasDefaultValue()} disabled="" {/if}  class="input-medium" name="fieldDefaultValue"
                                        data-fieldinfo='{ZEND_JSON::encode($FIELD_INFO)}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('defaultvalue'))}"
-                                       data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' />
+                                       data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' />
                             </div>
                         {else}
                             <input type="text" class="input-medium" data-validation-engine="validate[required,funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" {if !$FIELD_MODEL->hasDefaultValue()} disabled="" {/if}  name="fieldDefaultValue" value="{$FIELD_MODEL->get('defaultvalue')}" data-fieldinfo='{ZEND_JSON::encode($FIELD_INFO)}'/>
diff --git a/layouts/vlayout/modules/Settings/Webforms/resources/Field.js b/layouts/vlayout/modules/Settings/Webforms/resources/Field.js
index 7220fb1d895c8fa309ca953d39f9ff3a59b33a9c..a8d0027bc91a331157c21406bae18c6ddc6dfc16 100755
--- a/layouts/vlayout/modules/Settings/Webforms/resources/Field.js
+++ b/layouts/vlayout/modules/Settings/Webforms/resources/Field.js
@@ -108,7 +108,7 @@ Vtiger_Field_Js('Webforms_Currency_Field_Js',{},{
 	getUi : function() {
 		var html = '<div class="input-prepend">'+
 						'<span class="add-on">'+ this.getCurrencySymbol()+'</span>'+
-						'<input type="text" name="'+ this.getName() +'" value="'+  this.getValue() + '" class="input-medium" style="width:210px" data-decimal-seperator="'+this.getData().decimalSeperator+'" data-group-seperator="'+this.getData().groupSeperator+'"/>'+
+						'<input type="text" name="'+ this.getName() +'" value="'+  this.getValue() + '" class="input-medium" style="width:210px" data-decimal-separator="'+this.getData().decimalSeperator+'" data-group-separator="'+this.getData().groupSeperator+'"/>'+
 					'</div>';
 		var element = jQuery(html);
 		return this.addValidationToElement(element);
diff --git a/layouts/vlayout/modules/Users/resources/Edit.js b/layouts/vlayout/modules/Users/resources/Edit.js
index 23029954be44adb9335e2ee323f7d08559e98e82..2474cbecc0fc190f206e755a3c475192c6cd28da 100644
--- a/layouts/vlayout/modules/Users/resources/Edit.js
+++ b/layouts/vlayout/modules/Users/resources/Edit.js
@@ -70,7 +70,7 @@ Vtiger_Edit_Js("Users_Edit_Js",{},{
 			var groupingSeperatorValue = jQuery('[name="currency_grouping_separator"]', form).val();
 			var decimalSeperatorValue = jQuery('[name="currency_decimal_separator"]', form).val();
 			if(groupingSeperatorValue == decimalSeperatorValue){
-				Vtiger_Helper_Js.showPnotify(app.vtranslate('JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME'));
+				Vtiger_Helper_Js.showPnotify(app.vtranslate('JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME'));
 				e.preventDefault();
 			}
 			var userName = jQuery('input[name="user_name"]').val();
diff --git a/layouts/vlayout/modules/Vtiger/resources/AdvanceFilter.js b/layouts/vlayout/modules/Vtiger/resources/AdvanceFilter.js
index 0170d3242c7c9d648cdafb346865c4194035a5d1..a951585b0bd7f9ed8ac35c8adae8ecb7b61e00e2 100644
--- a/layouts/vlayout/modules/Vtiger/resources/AdvanceFilter.js
+++ b/layouts/vlayout/modules/Vtiger/resources/AdvanceFilter.js
@@ -309,8 +309,8 @@ jQuery.Class("Vtiger_AdvanceFilter_Js",{
 		fieldSpecificUi.find('[name="'+ fieldName +'"]').attr('data-value','value').removeAttr('data-validation-engine');
 		
 		if(fieldModel.getType() == 'currency') {
-			fieldSpecificUi.filter('[name="'+ fieldName +'"]').attr('data-decimal-seperator', fieldInfo.decimal_seperator).attr('data-group-seperator', fieldInfo.group_seperator);
-			fieldSpecificUi.find('[name="'+ fieldName +'"]').attr('data-decimal-seperator', fieldInfo.decimal_seperator).attr('data-group-seperator', fieldInfo.group_seperator);
+			fieldSpecificUi.filter('[name="'+ fieldName +'"]').attr('data-decimal-separator', fieldInfo.decimal_separator).attr('data-group-separator', fieldInfo.group_separator);
+			fieldSpecificUi.find('[name="'+ fieldName +'"]').attr('data-decimal-separator', fieldInfo.decimal_separator).attr('data-group-separator', fieldInfo.group_separator);
 		}
 		
 		fieldUiHolder.html(fieldSpecificUi);
diff --git a/layouts/vlayout/modules/Vtiger/uitypes/Currency.tpl b/layouts/vlayout/modules/Vtiger/uitypes/Currency.tpl
index 139cb21eedc906957d33509c88c646eb1cb3254a..d60d8ae3d373637d6804f317d72adde940fdc26a 100644
--- a/layouts/vlayout/modules/Vtiger/uitypes/Currency.tpl
+++ b/layouts/vlayout/modules/Vtiger/uitypes/Currency.tpl
@@ -19,7 +19,7 @@
 	<span class="add-on">{$USER_MODEL->get('currency_symbol')}</span>
 	<input id="{$MODULE}_editView_fieldName_{$FIELD_NAME}" type="text" class="input-medium currencyField" data-validation-engine="validate[{if $FIELD_MODEL->isMandatory() eq true} required,{/if}funcCall[Vtiger_Base_Validator_Js.invokeValidation]]" name="{$FIELD_MODEL->getFieldName()}"
 	data-fieldinfo='{$FIELD_INFO}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('fieldvalue'))}" {if !empty($SPECIAL_VALIDATOR)}data-validator='{Zend_Json::encode($SPECIAL_VALIDATOR)}'{/if} 
-	data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' data-number-of-decimal-places='{$USER_MODEL->get('no_of_currency_decimals')}'/>
+	data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' data-number-of-decimal-places='{$USER_MODEL->get('no_of_currency_decimals')}'/>
 </div>
 {else if ($FIELD_MODEL->get('uitype') eq '72') && ($FIELD_MODEL->getName() eq 'unit_price')}
 	<div class="input-prepend">
@@ -30,7 +30,7 @@
 			<span class="span10 row-fluid">
 				<input id="{$MODULE}-editview-fieldname-{$FIELD_NAME}" type="text" class="span6 unitPrice currencyField" name="{$FIELD_MODEL->getFieldName()}" data-validation-engine="validate[{if $FIELD_MODEL->isMandatory() eq true} required,{/if}funcCall[Vtiger_Base_Validator_Js.invokeValidation]]"
 			data-fieldinfo='{$FIELD_INFO}'  value="{$FIELD_MODEL->getDisplayValue($FIELD_MODEL->get('fieldvalue'))}" {if !empty($SPECIAL_VALIDATOR)}data-validator='{Zend_Json::encode($SPECIAL_VALIDATOR)}'{/if}
-			data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' data-number-of-decimal-places='{$USER_MODEL->get('no_of_currency_decimals')}'/>
+			data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' data-number-of-decimal-places='{$USER_MODEL->get('no_of_currency_decimals')}'/>
                                 {assign var=VIEW_NAME value={getPurifiedSmartyParameters('view')}}
 				{if $VIEW_NAME eq 'Edit'}
 					<a id="moreCurrencies" class="span cursorPointer">{vtranslate('LBL_MORE_CURRENCIES', $MODULE)}>></a>
@@ -47,7 +47,7 @@
 	<div class="row-fluid">
 		<span class="span1"><span class="add-on row-fluid">{$USER_MODEL->get('currency_symbol')}</span></span>
 		<span class="span7"><input type="text" class="row-fluid currencyField" name="{$FIELD_MODEL->getFieldName()}" data-validation-engine="validate[{if $FIELD_MODEL->isMandatory() eq true} required,{/if}funcCall[Vtiger_Base_Validator_Js.invokeValidation]]"
-		data-fieldinfo='{$FIELD_INFO}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('fieldvalue'))}" {if !empty($SPECIAL_VALIDATOR)}data-validator={Zend_Json::encode($SPECIAL_VALIDATOR)}{/if} data-decimal-seperator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-seperator='{$USER_MODEL->get('currency_grouping_separator')}' /></span>
+		data-fieldinfo='{$FIELD_INFO}' value="{$FIELD_MODEL->getEditViewDisplayValue($FIELD_MODEL->get('fieldvalue'))}" {if !empty($SPECIAL_VALIDATOR)}data-validator={Zend_Json::encode($SPECIAL_VALIDATOR)}{/if} data-decimal-separator='{$USER_MODEL->get('currency_decimal_separator')}' data-group-separator='{$USER_MODEL->get('currency_grouping_separator')}' /></span>
 	</div>
 </div>
 {/if}
diff --git a/layouts/vlayout/skins/style.less b/layouts/vlayout/skins/style.less
index 59b3ab0ee90efacc8c2af858254e93d50f4889f0..77489274cb01a48960a3edb89b99be0ec60db7d3 100644
--- a/layouts/vlayout/skins/style.less
+++ b/layouts/vlayout/skins/style.less
@@ -3167,7 +3167,7 @@ input[type="text"], input, textarea{
 
 .unselectedCell {
     background-color: @grayLighter;
-    color: @seperatorColor;
+    color: @separatorColor;
     white-space : nowrap;
 }
 
diff --git a/libraries/htmlpurifier/library/HTMLPurifier/ConfigSchema/schema/Attr.IDPrefixLocal.txt b/libraries/htmlpurifier/library/HTMLPurifier/ConfigSchema/schema/Attr.IDPrefixLocal.txt
index 2c5924a7ade81d45386a280a40b2721c93299731..0ac0da189b751562e71f5218a30a03104ad93734 100644
--- a/libraries/htmlpurifier/library/HTMLPurifier/ConfigSchema/schema/Attr.IDPrefixLocal.txt
+++ b/libraries/htmlpurifier/library/HTMLPurifier/ConfigSchema/schema/Attr.IDPrefixLocal.txt
@@ -9,6 +9,6 @@ have a seperate prefix that changes with each iteration.  This way,
 seperately submitted user content displayed on the same page doesn't
 clobber each other. Ideal values are unique identifiers for the content it
 represents (i.e. the id of the row in the database). Be sure to add a
-seperator (like an underscore) at the end.  Warning: this directive will
+separator (like an underscore) at the end.  Warning: this directive will
 not work unless %Attr.IDPrefix is set to a non-empty value!
 --# vim: et sw=4 sts=4
diff --git a/libraries/htmlpurifier/library/HTMLPurifier/ContentSets.php b/libraries/htmlpurifier/library/HTMLPurifier/ContentSets.php
index 3b6e96f5f56a8fee3e8f3bcf4e48d1be85cce14d..ad60d9991d70578fed69fe5d7b42b15ee6c985d9 100644
--- a/libraries/htmlpurifier/library/HTMLPurifier/ContentSets.php
+++ b/libraries/htmlpurifier/library/HTMLPurifier/ContentSets.php
@@ -7,7 +7,7 @@ class HTMLPurifier_ContentSets
 {
 
     /**
-     * List of content set strings (pipe seperators) indexed by name.
+     * List of content set strings (pipe separators) indexed by name.
      */
     public $info = array();
 
diff --git a/modules/Reports/ReportRun.php b/modules/Reports/ReportRun.php
index 69ac4d88e6b185095c70c473ec678effa13c6626..9b5a73fff205118cf91edeb4f9e4944a569dc11b 100644
--- a/modules/Reports/ReportRun.php
+++ b/modules/Reports/ReportRun.php
@@ -449,7 +449,8 @@ class ReportRun extends CRMEntity
                 } else if ($selectedfields[0] == "vtiger_crmentity" . $this->primarymodule) {
                     $columnSQL = "vtiger_crmentity." . $selectedfields[1] . " AS '" . decode_html($header_label) . "'";
                 } else {
-                    $columnSQL = $selectedfields[0] . "." . $selectedfields[1] . " AS '" . decode_html($header_label) . "'";
+                    $userformat=str_replace(array("dd-mm-yyyy","mm-dd-yyyy","yyyy-mm-dd"),array("%d-%m-%Y","%m-%d-%Y","%Y-%m-%d"),$current_user->date_format);
+                    $columnSQL = "date_format (" . $selectedfields[0] . "." . $selectedfields[1] . ",'$userformat') AS '" . decode_html($header_label) . "'";
                 }
                 $this->queryPlanner->addTable($selectedfields[0]);
             }
diff --git a/modules/Vtiger/helpers/Util.php b/modules/Vtiger/helpers/Util.php
index b1c39777a560008575a21c3766037ddc82d260c1..3d01000f7d2deef512b5bdb6d56c07cd8f07b1c3 100644
--- a/modules/Vtiger/helpers/Util.php
+++ b/modules/Vtiger/helpers/Util.php
@@ -163,7 +163,7 @@ class Vtiger_Util_Helper {
 			}
 		} else {
 			/**
-			 * To support strtotime() for 'mm-dd-yyyy' format the seperator should be '/'
+			 * To support strtotime() for 'mm-dd-yyyy' format the separator should be '/'
 			 * For more referrences
 			 * http://php.net/manual/en/datetime.formats.date.php
 			 */
@@ -220,7 +220,7 @@ class Vtiger_Util_Helper {
 		$displayTime = $hours .':'. $minutes .' '. $meridiem;
         
 		/**
-		 * To support strtotime() for 'mm-dd-yyyy' format the seperator should be '/'
+		 * To support strtotime() for 'mm-dd-yyyy' format the separator should be '/'
 		 * For more referrences
 		 * http://php.net/manual/en/datetime.formats.date.php
 		 */
diff --git a/modules/Vtiger/models/Field.php b/modules/Vtiger/models/Field.php
index 4b18173480d08603f9d850bd39e2daa1e62caa38..c912c6898207396a154fa85113188eab86d180bf 100644
--- a/modules/Vtiger/models/Field.php
+++ b/modules/Vtiger/models/Field.php
@@ -513,8 +513,8 @@ class Vtiger_Field_Model extends Vtiger_Field {
 		if($this->getFieldDataType() == 'currency') {
 			$currentUser = Users_Record_Model::getCurrentUserModel();
 			$this->fieldInfo['currency_symbol'] = $currentUser->get('currency_symbol');
-			$this->fieldInfo['decimal_seperator'] = $currentUser->get('currency_decimal_separator');
-			$this->fieldInfo['group_seperator'] = $currentUser->get('currency_grouping_separator');
+			$this->fieldInfo['decimal_separator'] = $currentUser->get('currency_decimal_separator');
+			$this->fieldInfo['group_separator'] = $currentUser->get('currency_grouping_separator');
 		}
 
 		if($this->getFieldDataType() == 'owner') {
diff --git a/modules/com_vtiger_workflow/VTSimpleTemplate.inc b/modules/com_vtiger_workflow/VTSimpleTemplate.inc
index 569a7217d23b522d05191f786824e38d68acf0da..eedaef15c8fdde27e526da90eaf67272de9211b1 100644
--- a/modules/com_vtiger_workflow/VTSimpleTemplate.inc
+++ b/modules/com_vtiger_workflow/VTSimpleTemplate.inc
@@ -176,7 +176,7 @@ class VTSimpleTemplate{
 											$parts = explode('x', $wsId);
 											$recordId = $parts[1];
 											$moduleName = $this->parent->getModuleName();
-											return "$site_URL/index.php?module=$moduleName&view=Detail&record=$recordId";
+											return "<a href='$site_URL/index.php?module=$moduleName&view=Detail&record=$recordId'>$moduleName</a>";
 			case 'portaldetailviewurl'	: 	$wsId = $this->parent->getId();
 											$parts = explode('x', $wsId);
 											$recordId = $parts[1];
@@ -185,15 +185,15 @@ class VTSimpleTemplate{
 											if($moduleName == 'HelpDesk') $recorIdName = 'ticketid';
 											if($moduleName == 'Faq') $recorIdName = 'faqid';
 											if($moduleName == 'Products') $recorIdName = 'productid';
-											return $PORTAL_URL.'/index.php?module='.$moduleName.'&action=index&'.$recorIdName.'='.$recordId.'&status=true';
+											return "<a href='" . $PORTAL_URL.'/index.php?module='.$moduleName.'&action=index&'.$recorIdName.'='.$recordId.'&status=true'."'>Portal</a>";
             case 'portalpdfurl'         :   $wsId = $this->parent->getId();
 											$parts = explode('x', $wsId);
 											$recordId = $parts[1];
 											$moduleName = $this->parent->getModuleName();
 											$recorIdName='id';
-											return $PORTAL_URL.'/index.php?module='.$moduleName.'&action=index&'.$recorIdName.'='.$recordId.'&downloadfile=true';
-			case 'siteurl'				:	return $site_URL;
-			case 'portalurl'			:	return $PORTAL_URL;
+											return "<a href='" . $PORTAL_URL.'/index.php?module='.$moduleName.'&action=index&'.$recorIdName.'='.$recordId.'&downloadfile=true'."'>Download</a>";
+			case 'siteurl'				:	return "<a href='$site_URL'>$site_URL</a>";
+			case 'portalurl'			:	return "<a href='$PORTAL_URL'>$PORTAL_URL</a>";
 			case 'logo'					:	return '<img src="cid:logo" />';
 
 			case 'recordId'				: list($moduleId, $recordId) = vtws_getIdComponents($this->parent->getId());
diff --git a/pkg/vtiger/modules/Webforms/settings/templates/resources/Field.js b/pkg/vtiger/modules/Webforms/settings/templates/resources/Field.js
index 7220fb1d895c8fa309ca953d39f9ff3a59b33a9c..a8d0027bc91a331157c21406bae18c6ddc6dfc16 100644
--- a/pkg/vtiger/modules/Webforms/settings/templates/resources/Field.js
+++ b/pkg/vtiger/modules/Webforms/settings/templates/resources/Field.js
@@ -108,7 +108,7 @@ Vtiger_Field_Js('Webforms_Currency_Field_Js',{},{
 	getUi : function() {
 		var html = '<div class="input-prepend">'+
 						'<span class="add-on">'+ this.getCurrencySymbol()+'</span>'+
-						'<input type="text" name="'+ this.getName() +'" value="'+  this.getValue() + '" class="input-medium" style="width:210px" data-decimal-seperator="'+this.getData().decimalSeperator+'" data-group-seperator="'+this.getData().groupSeperator+'"/>'+
+						'<input type="text" name="'+ this.getName() +'" value="'+  this.getValue() + '" class="input-medium" style="width:210px" data-decimal-separator="'+this.getData().decimalSeperator+'" data-group-separator="'+this.getData().groupSeperator+'"/>'+
 					'</div>';
 		var element = jQuery(html);
 		return this.addValidationToElement(element);
diff --git a/vtlib/thirdparty/parser/feed/simplepie.inc b/vtlib/thirdparty/parser/feed/simplepie.inc
index a7186fe0b8c8a7ea67010c2aa1a93a38ef79d3fe..5bfbb12a1e70b316384aaf0f2d30b22b1925c3e0 100644
--- a/vtlib/thirdparty/parser/feed/simplepie.inc
+++ b/vtlib/thirdparty/parser/feed/simplepie.inc
@@ -11830,7 +11830,7 @@ class SimplePie_Parse_Date
 	/**
 	 * Parse a superset of W3C-DTF (allows hyphens and colons to be omitted, as
 	 * well as allowing any of upper or lower case "T", horizontal tabs, or
-	 * spaces to be used as the time seperator (including more than one))
+	 * spaces to be used as the time separator (including more than one))
 	 *
 	 * @access protected
 	 * @return int Timestamp
diff --git a/languages/de_de/Users.php b/languages/de_de/Users.php
index f2d263ea4e5948e4fb4bafd19082f909bbc615e1..9cc2d6988c4a9d9b9d54c6486e0772b7cc506922 100644
--- a/languages/de_de/Users.php
+++ b/languages/de_de/Users.php
@@ -207,8 +207,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/en_gb/Users.php b/languages/en_gb/Users.php
index 4b49ee4db776b7be28d38c4001a3ffad6cf48445..edbf3790866e63ff97a8e3b76491d429bb50dd67 100644
--- a/languages/en_gb/Users.php
+++ b/languages/en_gb/Users.php
@@ -205,8 +205,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator can\'t be the same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator can\'t be the same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/en_us/Users.php b/languages/en_us/Users.php
index dc044f21888818df0e8bf7afaaacdbd83c320ebe..eab9b65bc53750f3dfb6e80cb5785ff79849e072 100644
--- a/languages/en_us/Users.php
+++ b/languages/en_us/Users.php
@@ -246,13 +246,13 @@ $languageStrings = array(
     'Asia/Magadan'  =>  '(UTC+12:00) Magadan',
     'Pacific/Tongatapu'  =>  '(UTC+13:00) Nukualofa',
     
     // currency seperatar in user preferance
       'LBL_Space' => 'Space',
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
@@ -246,13 +246,13 @@ $languageStrings = array(
     'Pacific/Tongatapu'  =>  '(UTC+13:00) Nukualofa',
     
-    // currency seperatar in user preferance
+    // currency separator in user preferance
       'LBL_Space' => 'Space',
 );
diff --git a/languages/es_mx/Users.php b/languages/es_mx/Users.php
index 8c60036cce1e76dc78d89518568370f85b3b68f1..689b6e00b73d31273c577a60f1174d11e4df0467 100644
--- a/languages/es_mx/Users.php
+++ b/languages/es_mx/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/fr_fr/Users.php b/languages/fr_fr/Users.php
index 9f5a328f69ac49ea9c83f7e4a7ce3b35850f0757..93ef8d8d97ddc987ff2326de9b48b60478ac50d0 100644
--- a/languages/fr_fr/Users.php
+++ b/languages/fr_fr/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/hu_hu/Users.php b/languages/hu_hu/Users.php
index 942d7f82a751d75f2cecebc901c09c12656d1d39..aa234831313a1722ff60e388c319b5a2ad381703 100644
--- a/languages/hu_hu/Users.php
+++ b/languages/hu_hu/Users.php
@@ -218,8 +218,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'A tizedesjel és az ezres elválasztó nem lehet ugyanaz.',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'A tizedesjel és az ezres elválasztó nem lehet ugyanaz.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Kérjük, hogy erősítse meg a jelszavát.',
 	'JS_ENTER_NEW_PASSWORD'=>'Kérjük, hogy adja meg az új jelszavát.',
 	'JS_ENTER_OLD_PASSWORD'=>'Kérjük, hogy adja meg a régi jelszavát.',
diff --git a/languages/it_it/Users.php b/languages/it_it/Users.php
index d583772aa47d4dadd4b9b304fb3b816d5db16720..6e4994b7177fc0fbcd9bdd9ae679ba1e67a97c81 100644
--- a/languages/it_it/Users.php
+++ b/languages/it_it/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/nl_nl/Users.php b/languages/nl_nl/Users.php
index 828084e5ce471aeebf9848e591bed384969bd7cb..fd22a75f83b1a7382de81c7661c2d6f7a35aece3 100644
--- a/languages/nl_nl/Users.php
+++ b/languages/nl_nl/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/pl_pl/Users.php b/languages/pl_pl/Users.php
index 04e85bb526b639d9e709d34ea2a3a99014eae5b9..7c3abe0877a3833810bdb866ea3120e470a4be2f 100644
--- a/languages/pl_pl/Users.php
+++ b/languages/pl_pl/Users.php
@@ -231,8 +231,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Wpisz swoje stare hasło.',
 	'JS_ENTER_NEW_PASSWORD'=>'Wpisz nowe hasło.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Wpisz potwierdzenie nowego hasła.',
diff --git a/languages/pt_br/Users.php b/languages/pt_br/Users.php
index 4d710c15f6427ce1798f3f5cc89d83fb16861e78..41bd301d9734ccde05e8adc80236125e5c373b30 100644
--- a/languages/pt_br/Users.php
+++ b/languages/pt_br/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/ro_ro/Users.php b/languages/ro_ro/Users.php
index 499ae85127126744feddf401a4d0f35ff68178cb..c61524dd3e5c7bd481d433fb77f261b528ff74cf 100644
--- a/languages/ro_ro/Users.php
+++ b/languages/ro_ro/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/ru_ru/Users.php b/languages/ru_ru/Users.php
index fd2afa16259026652cc8e5c4cd95019c06b99953..7cde4578fd1a53f3ae9e04e56a128c6c58b857e3 100644
--- a/languages/ru_ru/Users.php
+++ b/languages/ru_ru/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/languages/tr_tr/Users.php b/languages/tr_tr/Users.php
index c4d91a9018548beba7cdc8013b357a38efc2ef44..bb94df39c1eecbde3e88c0fa27eef7c586d8737e 100644
--- a/languages/tr_tr/Users.php
+++ b/languages/tr_tr/Users.php
@@ -200,8 +200,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/layouts/vlayout/modules/Users/resources/PreferenceEdit.js b/layouts/vlayout/modules/Users/resources/PreferenceEdit.js
index ebfee4339e498b6cfab7c0d6663075c6a01e526d..344a365c6fb8c3a81f3274989eb32b9507ca7c91 100644
--- a/layouts/vlayout/modules/Users/resources/PreferenceEdit.js
+++ b/layouts/vlayout/modules/Users/resources/PreferenceEdit.js
@@ -10,7 +10,7 @@
 Users_Edit_Js("Users_PreferenceEdit_Js",{
 	
 	/**
 	 * Function to register change event for currency seperator
 	 */
 	registerChangeEventForCurrencySeperator : function(){
 		var form = jQuery('form');
@@ -19,7 +19,7 @@ Users_Edit_Js("Users_PreferenceEdit_Js",{
 			var selectedValue = element.val();
 			var groupingSeperatorValue = jQuery('[name="currency_grouping_separator"]',form).data('selectedValue');
 			if(groupingSeperatorValue == selectedValue){
-				var message = app.vtranslate('JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME');
+				var message = app.vtranslate('JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME');
 				var params = {
 					text: message,
 					type: 'error'
@@ -38,7 +38,7 @@ Users_Edit_Js("Users_PreferenceEdit_Js",{
 			var selectedValue = element.val();
 			var decimalSeperatorValue = jQuery('[name="currency_decimal_separator"]',form).data('selectedValue');
 			if(decimalSeperatorValue == selectedValue){
-				var message = app.vtranslate('JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME');
+				var message = app.vtranslate('JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME');
 				var params = {
 					text: message,
 					type: 'error'
@@ -10,7 +10,7 @@
 	
 	/**
-	 * Function to register change event for currency seperator
+	 * Function to register change event for currency separator
 	 */
 	registerChangeEventForCurrencySeperator : function(){
diff --git a/pkg/vtiger/translations/Arabic_ar_ae/modules/Users.php b/pkg/vtiger/translations/Arabic_ar_ae/modules/Users.php
index a0ac0233d148a0c9dc68de12324d9912182e8084..7b6cd8739cb101e2969c55086f16fac6dbae13bd 100644
--- a/pkg/vtiger/translations/Arabic_ar_ae/modules/Users.php
+++ b/pkg/vtiger/translations/Arabic_ar_ae/modules/Users.php
@@ -190,8 +190,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/BrazilianLanguagePack_bz_bz/modules/Users.php b/pkg/vtiger/translations/BrazilianLanguagePack_bz_bz/modules/Users.php
index 5351d627622814c72ac82b3d03b9e836969b4dfc..189796b84fa10fc27a3018b5c39f12912ec73805 100644
--- a/pkg/vtiger/translations/BrazilianLanguagePack_bz_bz/modules/Users.php
+++ b/pkg/vtiger/translations/BrazilianLanguagePack_bz_bz/modules/Users.php
@@ -266,8 +266,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'O separador de casas decimais e separador de milhar não podem ser os mesmos',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'O separador de casas decimais e separador de milhar não podem ser os mesmos',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Por favor, digite confirmação da senha.',
 	'JS_ENTER_NEW_PASSWORD'=>'Por favor, digite sua nova senha.',
 	'JS_ENTER_OLD_PASSWORD'=>'Por favor, digite sua senha antiga.',
diff --git a/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Users.php b/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Users.php
index cac3d37ce606b6150c9af8f36c1b86c2578f62cd..c9407ab5f5f3d9886bc114b761180ca18f69d020 100644
--- a/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Users.php
+++ b/pkg/vtiger/translations/BritishLanguagePack_br_br/modules/Users.php
@@ -204,8 +204,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator can\'t be the same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator can\'t be the same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/Deutsch/modules/Users.php b/pkg/vtiger/translations/Deutsch/modules/Users.php
index 2091c68899a77729165a96a211b75fec72697be5..6928d4b417f013ce017f1254fcc559bab97db3b9 100644
--- a/pkg/vtiger/translations/Deutsch/modules/Users.php
+++ b/pkg/vtiger/translations/Deutsch/modules/Users.php
@@ -206,8 +206,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/Dutch/modules/Users.php b/pkg/vtiger/translations/Dutch/modules/Users.php
index 910246ed2d6c5a4dfc3bea31b84038bc6de179fe..b6631aa700fd7b3d565fc58fef157ea53c9d118c 100644
--- a/pkg/vtiger/translations/Dutch/modules/Users.php
+++ b/pkg/vtiger/translations/Dutch/modules/Users.php
@@ -250,8 +250,8 @@ $languageStrings['narrow'] = 'smal'; # auto added 2014-04-17 20:04:01
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimaal scheidingsteken en groepscheidingsteken kunnen niet hetzelfde zijn',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimaal scheidingsteken en groepscheidingsteken kunnen niet hetzelfde zijn',
 	'JS_ENTER_OLD_PASSWORD'=>'Voer a.u.b. uw oude wachtwoord in.',
 	'JS_ENTER_NEW_PASSWORD'=>'Voer a.u.b. uw nieuwe wachtwoord in.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Voer a.u.b. nogmaals uw wachtwoord in ter bevestiging.',
diff --git a/pkg/vtiger/translations/French/modules/Users.php b/pkg/vtiger/translations/French/modules/Users.php
index 13a7f798331b66bc4ac5b5a133356644f911dbec..916554843b370f68739571711acd70f9e0b6619e 100644
--- a/pkg/vtiger/translations/French/modules/Users.php
+++ b/pkg/vtiger/translations/French/modules/Users.php
@@ -199,8 +199,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/Hungarian/modules/Users.php b/pkg/vtiger/translations/Hungarian/modules/Users.php
index e42af7221182d8b0d558e37ebcd41c694b420393..24e129904ce606d84f78bf04444c106c811c550f 100644
--- a/pkg/vtiger/translations/Hungarian/modules/Users.php
+++ b/pkg/vtiger/translations/Hungarian/modules/Users.php
@@ -217,8 +217,8 @@ $languageStrings = array(
 );
 
 $jsLanguageStrings = array(
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'A tizedesjel és az ezres elválasztó nem lehet ugyanaz.',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'A tizedesjel és az ezres elválasztó nem lehet ugyanaz.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Kérjük, hogy erősítse meg a jelszavát.',
 	'JS_ENTER_NEW_PASSWORD'=>'Kérjük, hogy adja meg az új jelszavát.',
 	'JS_ENTER_OLD_PASSWORD'=>'Kérjük, hogy adja meg a régi jelszavát.',
diff --git a/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Users.php b/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Users.php
index 9d52ebda47d8b9bfea42cc961029d7b5b8aea4b3..1e7bdae03dec64a84947c529efb1e713f7bdb80b 100644
--- a/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Users.php
+++ b/pkg/vtiger/translations/ItalianLanguagePack_it_it/modules/Users.php
@@ -199,8 +199,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/MexicanSpanishLanguagePack_es_mx/modules/Users.php b/pkg/vtiger/translations/MexicanSpanishLanguagePack_es_mx/modules/Users.php
index 1330a019918cdcd90c6f8aa7669d0b16804e68e8..1af85f2d28b15c5dfe1a1af355d6a8aeb47c2322 100644
--- a/pkg/vtiger/translations/MexicanSpanishLanguagePack_es_mx/modules/Users.php
+++ b/pkg/vtiger/translations/MexicanSpanishLanguagePack_es_mx/modules/Users.php
@@ -211,8 +211,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'El separador de decimales y separador de grupos no pueden ser el mismo',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'El separador de decimales y separador de grupos no pueden ser el mismo',
 	'JS_ENTER_OLD_PASSWORD'=>'Ingresa tu contraseña actual.',
 	'JS_ENTER_NEW_PASSWORD'=>'Ingresa tu nueva contraseña.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Confirma tu nueva contraseña.',
diff --git a/pkg/vtiger/translations/PolishLanguagePack_pl_pl/modules/Users.php b/pkg/vtiger/translations/PolishLanguagePack_pl_pl/modules/Users.php
index 7f69a80df59505ea2cfd2769f3fe8c1de93a4bed..5e222cb41ff277aa214f972620aae476737a2169 100644
--- a/pkg/vtiger/translations/PolishLanguagePack_pl_pl/modules/Users.php
+++ b/pkg/vtiger/translations/PolishLanguagePack_pl_pl/modules/Users.php
@@ -230,8 +230,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Wpisz swoje stare hasło.',
 	'JS_ENTER_NEW_PASSWORD'=>'Wpisz nowe hasło.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Wpisz potwierdzenie nowego hasła.',
diff --git a/pkg/vtiger/translations/RomanianLanguagePack_rm_rm/modules/Users.php b/pkg/vtiger/translations/RomanianLanguagePack_rm_rm/modules/Users.php
index f3ed3c8ee3cbdf5e1c791b9449d13f1648a9b5f0..5885e45c293bfe3ed3ed33eabd48e4e111dc64ed 100644
--- a/pkg/vtiger/translations/RomanianLanguagePack_rm_rm/modules/Users.php
+++ b/pkg/vtiger/translations/RomanianLanguagePack_rm_rm/modules/Users.php
@@ -199,8 +199,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/Russian/modules/Users.php b/pkg/vtiger/translations/Russian/modules/Users.php
index c631269a9399ab9c9aee55e26dff953e963add4a..be77df2206e0d099e6bfa113db42a87c8d3dcb12 100644
--- a/pkg/vtiger/translations/Russian/modules/Users.php
+++ b/pkg/vtiger/translations/Russian/modules/Users.php
@@ -199,8 +199,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',
diff --git a/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Users.php b/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Users.php
index b53afd60dfec538a9174aa7d6a1fc05e6b9f030d..82d49fe005b4e8bd4080daad8fee9222ab2e63a8 100644
--- a/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Users.php
+++ b/pkg/vtiger/translations/TurkishLanguagePack_tr_tr/modules/Users.php
@@ -199,8 +199,8 @@ $languageStrings = array(
 
 $jsLanguageStrings = array(
 		
-	//Curency seperator validation messages
-	'JS_DECIMAL_SEPERATOR_AND_GROUPING_SEPERATOR_CANT_BE_SAME' => 'Decimal seperator and Grouping seperator cant be same',
+	//Curency separator validation messages
+	'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'Decimal separator and Grouping separator cant be same',
 	'JS_ENTER_OLD_PASSWORD'=>'Please enter your old password.',
 	'JS_ENTER_NEW_PASSWORD'=>'Please enter your new password.',
 	'JS_ENTER_CONFIRMATION_PASSWORD'=>'Please enter your password confirmation.',